# Autogenerated by nbdev

d = { 'settings': { 'allowed_cell_metadata_keys': '',
                'allowed_metadata_keys': '',
                'audience': 'Developers',
                'author': 'Hai Anh',
                'author_email': 'anhvth.226@gmail.com',
                'black_formatting': 'False',
                'branch': 'main',
                'clean_ids': 'True',
                'console_scripts': 'av_i2v=avcv.utils:av_i2v\n'
                                   'av_gdown=avcv.utils:download_file_from_google_drive\n'
                                   'av_v2i=avcv.utils:v2i\n'
                                   'av_debug_make_minidataset=avcv.debug:make_mini_coco\n'
                                   'av_dpython=avcv.debug:dpython\n'
                                   'av_v2c=avcv.coco:v2c\n'
                                   'av_image_convert=avcv.cli:convert_image',
                'copyright': 'https://github.com/anhvth',
                'custom_sidebar': 'False',
                'description': 'Python package utils for computer vision',
                'doc_baseurl': '/avcv/',
                'doc_host': 'https://anhvth.github.io',
                'doc_path': 'docs',
                'git_url': 'https://github.com/anhvth/avcv/tree/nbdev-convert/',
                'host': 'github',
                'jupyter_hooks': 'True',
                'keywords': 'computer vision',
                'language': 'English',
                'lib_name': 'avcv',
                'lib_path': 'avcv',
                'license': 'apache2',
                'min_python': '3.6',
                'nbs_path': './nbs',
                'readme_nb': 'index.ipynb',
                'recursive': 'False',
                'requirements': 'tqdm xxhash matplotlib scikit-learn scikit-image ipdb imutils mmcv opencv-python pandas fastcore openpyxl loguru pycocotools',
                'status': '2',
                'title': 'avcv',
                'tst_flags': '',
                'user': 'anhvth',
                'version': '0.0.48'},
  'syms': { 'avcv..ipynb_checkpoints.all-checkpoint': {},
            'avcv..ipynb_checkpoints.coco-checkpoint': { 'avcv..ipynb_checkpoints.coco-checkpoint.AvCOCO': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#avcoco',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.AvCOCO.createIndex': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#avcoco.createindex',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.AvCOCO.loadRes': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#avcoco.loadres',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.CocoDataset': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#cocodataset',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.CocoDataset.evaluate': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#cocodataset.evaluate',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.CocoDataset.imread': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#cocodataset.imread',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.CocoDataset.load_anns': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#cocodataset.load_anns',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.CocoDataset.visualize': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#cocodataset.visualize',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.DiagnoseCoco': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#diagnosecoco',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.DiagnoseCoco.find_false_samples': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#diagnosecoco.find_false_samples',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.DiagnoseCoco.imshow': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#diagnosecoco.imshow',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.PYTHON_VERSION': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#python_version',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.bbox_expand': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#bbox_expand',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.check_save_coco_dict': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#check_save_coco_dict',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.concat_coco': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#concat_coco',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.extract_coco': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#extract_coco',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.get_bboxes': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#get_bboxes',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.get_overlap_rate': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#get_overlap_rate',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.split_coco': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#split_coco',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.to_jpg': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#to_jpg',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.v2c': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#v2c',
                                                         'avcv..ipynb_checkpoints.coco-checkpoint.video_to_coco': 'https://anhvth.github.io/avcv/.ipynb_checkpoints.coco-checkpoint.html#video_to_coco'},
            'avcv.all': {},
            'avcv.cli': {'avcv.cli.convert_image': 'https://anhvth.github.io/avcv/cli.html#convert_image'},
            'avcv.coco': { 'avcv.coco.AvCOCO': 'https://anhvth.github.io/avcv/coco.html#avcoco',
                           'avcv.coco.AvCOCO.createIndex': 'https://anhvth.github.io/avcv/coco.html#avcoco.createindex',
                           'avcv.coco.AvCOCO.loadRes': 'https://anhvth.github.io/avcv/coco.html#avcoco.loadres',
                           'avcv.coco.CocoDataset': 'https://anhvth.github.io/avcv/coco.html#cocodataset',
                           'avcv.coco.CocoDataset.evaluate': 'https://anhvth.github.io/avcv/coco.html#cocodataset.evaluate',
                           'avcv.coco.CocoDataset.imread': 'https://anhvth.github.io/avcv/coco.html#cocodataset.imread',
                           'avcv.coco.CocoDataset.load_anns': 'https://anhvth.github.io/avcv/coco.html#cocodataset.load_anns',
                           'avcv.coco.CocoDataset.visualize': 'https://anhvth.github.io/avcv/coco.html#cocodataset.visualize',
                           'avcv.coco.DiagnoseCoco': 'https://anhvth.github.io/avcv/coco.html#diagnosecoco',
                           'avcv.coco.DiagnoseCoco.find_false_samples': 'https://anhvth.github.io/avcv/coco.html#diagnosecoco.find_false_samples',
                           'avcv.coco.DiagnoseCoco.imshow': 'https://anhvth.github.io/avcv/coco.html#diagnosecoco.imshow',
                           'avcv.coco.PYTHON_VERSION': 'https://anhvth.github.io/avcv/coco.html#python_version',
                           'avcv.coco.bbox_expand': 'https://anhvth.github.io/avcv/coco.html#bbox_expand',
                           'avcv.coco.check_save_coco_dict': 'https://anhvth.github.io/avcv/coco.html#check_save_coco_dict',
                           'avcv.coco.concat_coco': 'https://anhvth.github.io/avcv/coco.html#concat_coco',
                           'avcv.coco.extract_coco': 'https://anhvth.github.io/avcv/coco.html#extract_coco',
                           'avcv.coco.get_bboxes': 'https://anhvth.github.io/avcv/coco.html#get_bboxes',
                           'avcv.coco.get_overlap_rate': 'https://anhvth.github.io/avcv/coco.html#get_overlap_rate',
                           'avcv.coco.split_coco': 'https://anhvth.github.io/avcv/coco.html#split_coco',
                           'avcv.coco.to_jpg': 'https://anhvth.github.io/avcv/coco.html#to_jpg',
                           'avcv.coco.v2c': 'https://anhvth.github.io/avcv/coco.html#v2c',
                           'avcv.coco.video_to_coco': 'https://anhvth.github.io/avcv/coco.html#video_to_coco'},
            'avcv.debug': { 'avcv.debug.dpython': 'https://anhvth.github.io/avcv/debug.html#dpython',
                            'avcv.debug.make_mini_coco': 'https://anhvth.github.io/avcv/debug.html#make_mini_coco'},
            'avcv.dist_utils': { 'avcv.dist_utils.all_gather': 'https://anhvth.github.io/avcv/dist_utils.html#all_gather',
                                 'avcv.dist_utils.all_gatherv': 'https://anhvth.github.io/avcv/dist_utils.html#all_gatherv',
                                 'avcv.dist_utils.all_reduce': 'https://anhvth.github.io/avcv/dist_utils.html#all_reduce',
                                 'avcv.dist_utils.gather_grad': 'https://anhvth.github.io/avcv/dist_utils.html#gather_grad',
                                 'avcv.dist_utils.get_rank': 'https://anhvth.github.io/avcv/dist_utils.html#get_rank',
                                 'avcv.dist_utils.get_world_size': 'https://anhvth.github.io/avcv/dist_utils.html#get_world_size',
                                 'avcv.dist_utils.primary': 'https://anhvth.github.io/avcv/dist_utils.html#primary',
                                 'avcv.dist_utils.rank0_to_all': 'https://anhvth.github.io/avcv/dist_utils.html#rank0_to_all',
                                 'avcv.dist_utils.reduce_loss_dict': 'https://anhvth.github.io/avcv/dist_utils.html#reduce_loss_dict',
                                 'avcv.dist_utils.reduce_sum': 'https://anhvth.github.io/avcv/dist_utils.html#reduce_sum',
                                 'avcv.dist_utils.setup_distributed': 'https://anhvth.github.io/avcv/dist_utils.html#setup_distributed',
                                 'avcv.dist_utils.synchronize': 'https://anhvth.github.io/avcv/dist_utils.html#synchronize'},
            'avcv.process': { 'avcv.process.multi_process': 'https://anhvth.github.io/avcv/process.html#multi_process',
                              'avcv.process.multi_thread': 'https://anhvth.github.io/avcv/process.html#multi_thread'},
            'avcv.utils': { 'avcv.utils.AVCV_CACHE_DIR': 'https://anhvth.github.io/avcv/utils.html#avcv_cache_dir',
                            'avcv.utils.ICACHE': 'https://anhvth.github.io/avcv/utils.html#icache',
                            'avcv.utils.TimeLoger': 'https://anhvth.github.io/avcv/utils.html#timeloger',
                            'avcv.utils.TimeLoger.start': 'https://anhvth.github.io/avcv/utils.html#timeloger.start',
                            'avcv.utils.TimeLoger.update': 'https://anhvth.github.io/avcv/utils.html#timeloger.update',
                            'avcv.utils.VERBOSE': 'https://anhvth.github.io/avcv/utils.html#verbose',
                            'avcv.utils.av_i2v': 'https://anhvth.github.io/avcv/utils.html#av_i2v',
                            'avcv.utils.find_contours': 'https://anhvth.github.io/avcv/utils.html#find_contours',
                            'avcv.utils.generate_tmp_filename': 'https://anhvth.github.io/avcv/utils.html#generate_tmp_filename',
                            'avcv.utils.get_files': 'https://anhvth.github.io/avcv/utils.html#get_files',
                            'avcv.utils.get_md5': 'https://anhvth.github.io/avcv/utils.html#get_md5',
                            'avcv.utils.get_name': 'https://anhvth.github.io/avcv/utils.html#get_name',
                            'avcv.utils.identify': 'https://anhvth.github.io/avcv/utils.html#identify',
                            'avcv.utils.images_to_video': 'https://anhvth.github.io/avcv/utils.html#images_to_video',
                            'avcv.utils.imemoize': 'https://anhvth.github.io/avcv/utils.html#imemoize',
                            'avcv.utils.is_interactive': 'https://anhvth.github.io/avcv/utils.html#is_interactive',
                            'avcv.utils.memoize': 'https://anhvth.github.io/avcv/utils.html#memoize',
                            'avcv.utils.mkdir': 'https://anhvth.github.io/avcv/utils.html#mkdir',
                            'avcv.utils.printc': 'https://anhvth.github.io/avcv/utils.html#printc',
                            'avcv.utils.put_text': 'https://anhvth.github.io/avcv/utils.html#put_text',
                            'avcv.utils.self_memoize': 'https://anhvth.github.io/avcv/utils.html#self_memoize',
                            'avcv.utils.v2i': 'https://anhvth.github.io/avcv/utils.html#v2i',
                            'avcv.utils.video_to_images': 'https://anhvth.github.io/avcv/utils.html#video_to_images'},
            'avcv.visualize': { 'avcv.visualize.Board': 'https://anhvth.github.io/avcv/visualize.html#board',
                                'avcv.visualize.Board.clear': 'https://anhvth.github.io/avcv/visualize.html#board.clear',
                                'avcv.visualize.Board.draw': 'https://anhvth.github.io/avcv/visualize.html#board.draw',
                                'avcv.visualize.Board.img_concat': 'https://anhvth.github.io/avcv/visualize.html#board.img_concat',
                                'avcv.visualize.Board.lazy_img_concat': 'https://anhvth.github.io/avcv/visualize.html#board.lazy_img_concat',
                                'avcv.visualize.Board.set_line_text': 'https://anhvth.github.io/avcv/visualize.html#board.set_line_text',
                                'avcv.visualize.Board.show': 'https://anhvth.github.io/avcv/visualize.html#board.show',
                                'avcv.visualize.COCO_COLORS': 'https://anhvth.github.io/avcv/visualize.html#coco_colors',
                                'avcv.visualize.bbox_visualize': 'https://anhvth.github.io/avcv/visualize.html#bbox_visualize',
                                'avcv.visualize.imshow': 'https://anhvth.github.io/avcv/visualize.html#imshow',
                                'avcv.visualize.plot_images': 'https://anhvth.github.io/avcv/visualize.html#plot_images',
                                'avcv.visualize.show': 'https://anhvth.github.io/avcv/visualize.html#show',
                                'avcv.visualize.tensor2imgs': 'https://anhvth.github.io/avcv/visualize.html#tensor2imgs'}}}